@@ -1,3 +1,4 @@
+# 2012-08-30 CJS fixed problem with missing values in any() and all()
 # 2011-06-13 CJS added p-values to results
 # 2010-11-25 CJS pretty printing of final estimates of population sizes
 # 2010-09-06 CJS forced input vectors to be vectors
@@ -106,36 +107,36 @@ if(length(logitP.cov) %% length(n1) != 0){
         length(n1),length(logitP.cov),dim(logitP.cov),"\n")
    return()}
 #  2. Check that m2<= n1
-if(any(m2>n1)){
+if(any(m2>n1,na.rm=TRUE)){
    cat("***** ERROR ***** m2 must be <= n1. The arguments are \n n1:",n1,"\n m2:",m2,"\n")
    return()}
 #  3. Elements of bad.m2, bad.u2.A.YoY, bad.u2.A.1, bad.u2.N.YoY, bad.u2.N.1, and hatch.after.YoY must belong to time
-if(!all(bad.m2 %in% time)){
+if(!all(bad.m2 %in% time,na.rm=TRUE)){
    cat("***** ERROR ***** bad.m2 must be elements of strata identifiers. You entered \n bad.m2:",bad.m2,"\n Strata identifiers are \n time:",time, "\n")
    return()}
-if(!all(bad.u2.A.YoY %in% time)){
+if(!all(bad.u2.A.YoY %in% time,na.rm=TRUE)){
    cat("***** ERROR ***** bad.u2.A.YoY must be elements of strata identifiers. You entered \n bad.u2.A.YoY:",
        bad.u2.A.YoY,"\n Strata identifiers are \n time:",time, "\n")
    return()}
-if(!all(bad.u2.A.1 %in% time)){
+if(!all(bad.u2.A.1 %in% time, na.rm=TRUE)){
    cat("***** ERROR ***** bad.u2.A.1 must be elements of strata identifiers. You entered \n bad.u2.A.1:",
        bad.u2.A.1,"\n Strata identifiers are \n time:",time, "\n")
    return()}
-if(!all(bad.u2.N.YoY %in% time)){
+if(!all(bad.u2.N.YoY %in% time, na.rm=TRUE)){
    cat("***** ERROR ***** bad.u2.N.YoY must be elements of strata identifiers. You entered \n bad.u2.N.YoY:",
        bad.u2.N.YoY,"\n Strata identifiers are \n time:",time, "\n")
    return()}
-if(!all(bad.u2.N.1 %in% time)){
+if(!all(bad.u2.N.1 %in% time, na.rm=TRUE)){
    cat("***** ERROR ***** bad.u2.N.1 must be elements of strata identifiers. You entered \n bad.u2.N.1:",
        bad.u2.N.1,"\n Strata identifiers are \n time:",time, "\n")
    return()}
-if(!all(hatch.after.YoY %in% time)){
+if(!all(hatch.after.YoY %in% time, na.rm=TRUE)){
    cat("***** ERROR ***** hatch.after.YoY must be elements of strata identifiers. You entered \n hatch.after.YoY:",
    hatch.after.YoY,"\n Strata identifiers are \n time:",time, "\n")
    return()}
 
 #  4. check that strata numbers are contiguous between smallest and largest value of the strata numbers
-if( any(seq(min(time),max(time),1) != time)){
+if( any(seq(min(time),max(time),1) != time,na.rm=TRUE)){
    cat("***** ERROR ***** Strata numbers must be contiguous. \n You entered :", time, "\n")
    return()
 }
