@@ -1,5 +1,6 @@
 ## Yet to do - add bayesian p-value plots/ add p-values to results
 
+## 2012-08-30 CJS fixed problem in any() and all() in error checking with NAs
 ## 2011-02-21 CJS changed u2 to new.u2 in code for expanded.m2
 ## 2011-02-19 CJS First development
 
@@ -108,20 +109,20 @@ sampfrac <- as.vector(sampfrac)
     stop("***** ERROR ***** m2[i,+] must be <= n1[i]. The arguments are \n n1:",n1,"\n m2:",m2,"\n")
 
   ##  3. Elements of bad.m2 and jump.after must belong to time
-  if(!all(bad.n1 %in% time))
+  if(!all(bad.n1 %in% time, na.rm=TRUE))
     stop("***** ERROR ***** bad.n1 must be elements of strata identifiers. You entered \n bad.n1:",bad.n1,"\n Strata identifiers are \n time:",time, "\n")
 
-  if(!all(bad.m2 %in% time))
+  if(!all(bad.m2 %in% time, na.rm=TRUE))
     stop("***** ERROR ***** bad.m2 must be elements of strata identifiers. You entered \n bad.m2:",bad.m2,"\n Strata identifiers are \n time:",time, "\n")
 
-  if(!all(bad.u2 %in% time))
+  if(!all(bad.u2 %in% time, na.rm=TRUE))
     stop("***** ERROR ***** bad.u2 must be elements of strata identifiers. You entered \n bad.u2:",bad.u2,"\n Strata identifiers are \n time:",time, "\n")
 
-  if(!all(jump.after %in% time))
+  if(!all(jump.after %in% time, na.rm=TRUE))
     stop("***** ERROR ***** jump.after must be elements of strata identifiers. You entered \n jump.after:",jump.after,"\n Strata identifiers are \n time:",time, "\n")
 
   #  4. check that index of logitP.fixed belong to time
-  if(!all(logitP.fixed %in% time)){
+  if(!all(logitP.fixed %in% time, na.rm=TRUE)){
     cat("***** ERROR ***** logitP.fixed must be elements of strata identifiers. You entered \n logitP.fixed:",logitP.fixed,"\n Strata identifiers are \n time:",time, "\n")
     return()}
   if(length(logitP.fixed)!=length(logitP.fixed.values)){
